# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProcessJobConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'process_job_id': 'str',
        'client_id': 'str',
        'version': 'str'
    }

    attribute_map = {
        'process_job_id': 'processJobId',
        'client_id': 'clientId',
        'version': 'version'
    }

    def __init__(self, process_job_id=None, client_id=None, version=None):  # noqa: E501
        """ProcessJobConfig - a model defined in Swagger"""  # noqa: E501
        self._process_job_id = None
        self._client_id = None
        self._version = None
        self.discriminator = None
        self.process_job_id = process_job_id
        self.client_id = client_id
        self.version = version

    @property
    def process_job_id(self):
        """Gets the process_job_id of this ProcessJobConfig.  # noqa: E501


        :return: The process_job_id of this ProcessJobConfig.  # noqa: E501
        :rtype: str
        """
        return self._process_job_id

    @process_job_id.setter
    def process_job_id(self, process_job_id):
        """Sets the process_job_id of this ProcessJobConfig.


        :param process_job_id: The process_job_id of this ProcessJobConfig.  # noqa: E501
        :type: str
        """
        if process_job_id is None:
            raise ValueError("Invalid value for `process_job_id`, must not be `None`")  # noqa: E501

        self._process_job_id = process_job_id

    @property
    def client_id(self):
        """Gets the client_id of this ProcessJobConfig.  # noqa: E501


        :return: The client_id of this ProcessJobConfig.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this ProcessJobConfig.


        :param client_id: The client_id of this ProcessJobConfig.  # noqa: E501
        :type: str
        """
        if client_id is None:
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def version(self):
        """Gets the version of this ProcessJobConfig.  # noqa: E501


        :return: The version of this ProcessJobConfig.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ProcessJobConfig.


        :param version: The version of this ProcessJobConfig.  # noqa: E501
        :type: str
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProcessJobConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessJobConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
